==> gt-xsd-wps-C105.24.2.01-sources.jar: org/geotools/wps/bindings/ComplexDataTypeBinding.java <==
/*
 *    GeoTools - The Open Source Java GIS Toolkit
 *    http://geotools.org
 *
 *    (C) 2018 - 2016, Open Source Geospatial Foundation (OSGeo)
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    version 2.1 of the License.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */

package org.geotools.wps.bindings;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.xml.namespace.QName;
import net.opengis.wps10.ComplexDataType;
import net.opengis.wps10.Wps10Factory;
import org.eclipse.xsd.XSDElementDeclaration;
import org.geotools.wps.WPS;
import org.geotools.xs.XS;
import org.geotools.xsd.AbstractComplexBinding;
import org.geotools.xsd.ElementInstance;
import org.geotools.xsd.EncoderDelegate;
import org.geotools.xsd.Node;

/**
 * &lt;complexType name="ComplexDataType" mixed="true"> &lt;annotation> &lt;documentation>Complex
 * data (such as an image), including a definition of the complex value data structure (i.e.,
 * schema, format, and encoding). May be an ows:Manifest data structure.&lt;/documentation>
 * &lt;/annotation> &lt;complexContent mixed="true"> &lt;extension base="anyType">
 * &lt;attributeGroup ref="wps:ComplexDataEncoding"/> &lt;/extension> &lt;/complexContent>
 * &lt;/complexType>
 *
 * @author Justin Deoliveira, OpenGEO
 */
public class ComplexDataTypeBinding extends AbstractComplexBinding {
    private Wps10Factory factory;

    public ComplexDataTypeBinding(Wps10Factory factory) {
        this.factory = factory;
    }

    public QName getTarget() {
        return WPS.ComplexDataType;
    }

    public Class<?> getType() {
        return ComplexDataType.class;
    }

    public int getExecutionMode() {
        return OVERRIDE;
    }

    public Object getProperty(Object object, QName name) throws Exception {
        ComplexDataType data = (ComplexDataType) object;

        if ("schema".equals(name.getLocalPart())) {
            return data.getSchema();
        }

        if ("mimeType".equals(name.getLocalPart())) {
            return data.getMimeType();
        }

        if ("encoding".equals(name.getLocalPart())) {
            return data.getEncoding();
        }

        return super.getProperty(object, name);
    }

    /*
    	NodeImpl -> JTS.Polygon
    */
    public Object parse(ElementInstance instance, Node node, Object value) throws Exception {
        ComplexDataType data = factory.createComplexDataType();

        if (node.hasAttribute("schema")) {
            data.setSchema(node.getAttributeValue("schema").toString());
        }
        if (node.hasAttribute("mimeType")) {
            data.setMimeType(node.getAttributeValue("mimeType").toString());
        }
        if (node.hasAttribute("encoding")) {
            data.setEncoding(node.getAttributeValue("encoding").toString());
        }

        for (Iterator i = node.getChildren().iterator(); i.hasNext(); ) {
            Node c = (Node) i.next();
            data.getData().add(c.getValue());
        }

        return data;
    }

    @Override
    public List getProperties(Object object, XSDElementDeclaration element) throws Exception {
        ComplexDataType complex = (ComplexDataType) object;
        if (!complex.getData().isEmpty() && complex.getData().get(0) instanceof EncoderDelegate) {
            EncoderDelegate delegate = (EncoderDelegate) complex.getData().get(0);
            List properties = new ArrayList();
            properties.add(new Object[] {XS.ANYTYPE, delegate});

            return properties;
        }

        return null;
    }
}

==> gt-xsd-wps-C105.33.1.00-sources.jar: org/geotools/wps/bindings/ComplexDataTypeBinding.java <==
/*
 *    GeoTools - The Open Source Java GIS Toolkit
 *    http://geotools.org
 *
 *    (C) 2018 - 2016, Open Source Geospatial Foundation (OSGeo)
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    version 2.1 of the License.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */

package org.geotools.wps.bindings;

import java.util.ArrayList;
import java.util.List;
import javax.xml.namespace.QName;
import net.opengis.wps10.ComplexDataType;
import net.opengis.wps10.Wps10Factory;
import org.eclipse.xsd.XSDElementDeclaration;
import org.geotools.wps.WPS;
import org.geotools.xs.XS;
import org.geotools.xsd.AbstractComplexBinding;
import org.geotools.xsd.ElementInstance;
import org.geotools.xsd.EncoderDelegate;
import org.geotools.xsd.Node;

/**
 * &lt;complexType name="ComplexDataType" mixed="true"> &lt;annotation> &lt;documentation>Complex data (such as an
 * image), including a definition of the complex value data structure (i.e., schema, format, and encoding). May be an
 * ows:Manifest data structure.&lt;/documentation> &lt;/annotation> &lt;complexContent mixed="true"> &lt;extension
 * base="anyType"> &lt;attributeGroup ref="wps:ComplexDataEncoding"/> &lt;/extension> &lt;/complexContent>
 * &lt;/complexType>
 *
 * @author Justin Deoliveira, OpenGEO
 */
public class ComplexDataTypeBinding extends AbstractComplexBinding {
    private Wps10Factory factory;

    public ComplexDataTypeBinding(Wps10Factory factory) {
        this.factory = factory;
    }

    @Override
    public QName getTarget() {
        return WPS.ComplexDataType;
    }

    @Override
    public Class<?> getType() {
        return ComplexDataType.class;
    }

    @Override
    public int getExecutionMode() {
        return OVERRIDE;
    }

    @Override
    public Object getProperty(Object object, QName name) throws Exception {
        ComplexDataType data = (ComplexDataType) object;

        if ("schema".equals(name.getLocalPart())) {
            return data.getSchema();
        }

        if ("mimeType".equals(name.getLocalPart())) {
            return data.getMimeType();
        }

        if ("encoding".equals(name.getLocalPart())) {
            return data.getEncoding();
        }

        return super.getProperty(object, name);
    }

    /*
    	NodeImpl -> JTS.Polygon
    */
    @Override
    @SuppressWarnings("unchecked")
    public Object parse(ElementInstance instance, Node node, Object value) throws Exception {
        ComplexDataType data = factory.createComplexDataType();

        if (node.hasAttribute("schema")) {
            data.setSchema(node.getAttributeValue("schema").toString());
        }
        if (node.hasAttribute("mimeType")) {
            data.setMimeType(node.getAttributeValue("mimeType").toString());
        }
        if (node.hasAttribute("encoding")) {
            data.setEncoding(node.getAttributeValue("encoding").toString());
        }

        for (Node c : node.getChildren()) {
            data.getData().add(c.getValue());
        }

        return data;
    }

    @Override
    public List<Object[]> getProperties(Object object, XSDElementDeclaration element) throws Exception {
        ComplexDataType complex = (ComplexDataType) object;
        if (!complex.getData().isEmpty() && complex.getData().get(0) instanceof EncoderDelegate) {
            EncoderDelegate delegate = (EncoderDelegate) complex.getData().get(0);
            List<Object[]> properties = new ArrayList<>();
            properties.add(new Object[] {XS.ANYTYPE, delegate});
            return properties;
        }

        return null;
    }
}
